interface RawHeaders {
    "Content-Type": string;
    "Content-Length"?: string;
}
interface FormDataEncoderHeaders extends RawHeaders {
    "content-type": string;
    "content-length"?: string;
}

interface FileLike {
    readonly name: string;
    readonly type: string;
    readonly size: number;
    readonly lastModified: number;
    stream(): ReadableStream<Uint8Array> | AsyncIterable<Uint8Array>;
    readonly [Symbol.toStringTag]?: string;
}

type FormDataEntryValue = string | FileLike;
interface FormDataLike {
    append(name: string, value: unknown, fileName?: string): void;
    getAll(name: string): FormDataEntryValue[];
    entries(): IterableIterator<[string, FormDataEntryValue]>;
    [Symbol.iterator](): IterableIterator<[string, FormDataEntryValue]>;
    readonly [Symbol.toStringTag]?: string;
}

interface FormDataEncoderOptions {
    enableAdditionalHeaders?: boolean;
}
declare class FormDataEncoder {
    #private;
    readonly boundary: string;
    readonly contentType: string;
    readonly contentLength: string | undefined;
    readonly headers: Readonly<FormDataEncoderHeaders>;
    constructor(form: FormDataLike);
    constructor(form: FormDataLike, boundary: string);
    constructor(form: FormDataLike, options: FormDataEncoderOptions);
    constructor(form: FormDataLike, boundary: string, options?: FormDataEncoderOptions);
    values(): Generator<Uint8Array | FileLike, void, undefined>;
    encode(): AsyncGenerator<Uint8Array, void, undefined>;
    [Symbol.iterator](): Generator<Uint8Array | FileLike, void, undefined>;
    [Symbol.asyncIterator](): AsyncGenerator<Uint8Array, void, undefined>;
}

declare const isFile: (value: unknown) => value is FileLike;

declare const isFormData: (value: unknown) => value is FormDataLike;

export { FileLike, FormDataEncoder, FormDataEncoderOptions, FormDataEntryValue, FormDataLike, isFile, isFormData };
